async fn process_with_json_response_internal<E>(
request: RequestBuilder,
) -> Result<String, Error<E>>Expand description
process_with_json_response is generic, which means it gets monomorphized for every type it’s used with. This function contains the non-generic logic for processing the response so that it doesn’t get duplicated.